<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Sluit (%1) </translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Inklappen</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Uitklappen</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Wegklikken alarm</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%1% van %Ln minuut</numerusform>
            <numerusform>%1% van %Ln minuten</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%1% of %Ln word(s)</source>
        <translation>
            <numerusform>%1% van %Ln woord</numerusform>
            <numerusform>%1% van %Ln woorden</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln woord</numerusform>
            <numerusform>%Ln woorden</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minuut</numerusform>
            <numerusform>%Ln minuten</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Dagelijkse voortgang</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Langste serie</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Huidige serie</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n dag</numerusform>
            <numerusform>%n dagen</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%1% of daily goal</source>
        <translation>%1% van dagelijkse doel</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Taal instellen</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(naamloos %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Alleen lezen)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; kan niet opgeslagen worden.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Opslaan als</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; kan niet overschreven worden.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Bestand hernoemen</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; kan niet hernoemd worden.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Herladen bestamd</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Bestand &apos;%1&apos; herladen van disk</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Alle niet bewaarde wijzigingen zullen verloren gaan</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Herladen</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Geen naam %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Opslaan als kale tekst zal alle opmaak verwijderen. Opmaak verwijderen ?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Bestand is gewijzigd</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Bestand %1 is veranderd door een ander programma</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Moet het bestand opnieuw geladen worden ?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Herladen</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Negeren</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Bestand is verwijderd</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Bestand %1 is verwijderd door een andere applicatie</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Bestand opslaan of afsluiten ?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Kan archief niet openen</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Zoeken naar:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Vervangen door:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Hoofd-/kleine letters negeren</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Alleen hele woorden</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Regulieren expressies</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Naar begin zoeken</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Naar einde zoeken</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Zoek</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Vervang</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Vervang &amp;Alles</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Vervangen</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform> %n vondst vervangen?</numerusform>
            <numerusform> %n vondsten vervangen?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Zoekterm niet gevonden.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument Tekst </translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument platte XML</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich text formaat</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Platte tekst</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Alle bestanden</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Alle ondersteunde bestanden</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Spelling controleren ...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(geen suggestie gevonden)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Plaatje openen</translation>
    </message>
    <message>
        <source>Images(%1)</source>
        <translation>Plaatjes(%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Taal selecteren:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systeemtaal&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Let op</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Graag de applicatie herstarten om de taalverandering door te voeren.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Kan archief niet openen</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Instellungen</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistieken</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Werkbalk</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Spellingscontrole</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Woordenboek kiezen</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Archief kan niet geopend worden.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Dit archief bevat geen bruikbare woordenlijst.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Snelkoppelingen</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Een of meerdere snelkoppelingen conflicteren. Toch doorgaan ?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Het woordenboek %1 bestaat al. Deze vervangen ?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Dagelijks doel</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Niets</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minuten:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Woorden:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Bewerking</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Verticaal centreren</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Blok invoeg cursor</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Afgevlakte letters</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Typemachine geluiden</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Slimme  aanhalingstekens:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dubbel</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Enkel</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Scenes</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Deelstreep</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Onthou cursor positie</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Woordtelling</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Paginatelling</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Paragraaftelling</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Tekentelling</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Tekens:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Paragrafen:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algoritme voor woordtelling</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Dagelijkse voortgang naar 0 toe zetten ?</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Huidige directory verwijderen</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Schrijf &quot;byte order&quot; markering in platte tekst bestanden</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Standaard formaat</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Gebruikers interface</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Scrollbar altijd tonen</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Top bar altijd tonen</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Bottom bar altijd tonen</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Reset vandaag</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Geschiedenis</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Onthou geschiedenis</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Toon serie</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Minimale voortgang voor serie</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Woordgrenzen bepalen</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Tekentelling door 6 delen</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Tel elke letter als een woord</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Manier van pagina tellen</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stijl</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Alleen iconen</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Alleen tekst</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Tekst naast iconen</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Tekst onder Iconen</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Tekst positie:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Acties</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Naar boven verschuiven</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Naar onder verschuiven</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Scheidingsteken toevoegen</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Commando</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Snelkoppeling</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Actie</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Spelling controleren terwijl je typt</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Woorden in HOOFDLETTERS negeren</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Woorden met getallen negeren</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Taal</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Persoonlijke woordenboek</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Niet ondersteund RTF bestand</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Onverwacht het einde van het bestand bereikt.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl-Shift-Down</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Verplaats de scene omhoog</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl-Shift-Up</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Schakel scene lijst</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift-F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Laat scene lijst (%1) zien</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Verberg scene lijst (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filteren</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Verplaats Scenes naar beneden</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Vergroot of verklein scene lijst</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Sessies beheren</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>S&amp;essies</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nieuw</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Hernoemen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Wissel naar</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nieuwe sessie</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Kopieer sessie</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Sessie hernoemen</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Sessie verwijderen ?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Sessie naam:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>De sessie naam is al in gebruik.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Nieuw...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Crtl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Beheren...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+B</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Leegmaken</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Terugzetten naar standaard instellingen</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Snelkoppeling</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Vervang aanhalingstekens...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Even geduld</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Spellingcontrole</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Toevoegen</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Negeren</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>Negeer &amp;Alles</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Verander</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>V&amp;erander Alles</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Niet in woordenboek:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Vervang door:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Spelling controleren ...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Afbreken</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Even geduld</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Ga door met controleren vanaf het begin van het bestand</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Spellingcontrole klaar.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Symbolen</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Recent gebruikte symbolen</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Alle symbolen</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Invoegen</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Blokken</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Naamloos %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Geen plaatje</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Getegeld.</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Gecentreerd</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Uitgerekt</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Geschaald</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Bedekking:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Positie:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Breedte:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Afronden hoeken achtergrond tekst</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Straal:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Achtergrond tekst onduidelijker maken</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Schaduw achtergrond tekst</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Verticale verschuiving</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Randen</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Window:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Pagina:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Eerste lijn inspringen</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Boven:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Onder:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Verwijder</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Thema bewerken</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Window Achtergrond</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Kleur:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Plaatje:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>  Pixel</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Achtergrond tekst</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Lettertype:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Spelfout:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Lijn afstand</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Enkel</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>Anderhalve lijn</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dubbele lijn</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proportioneel</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Hoogte:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Paragraaf uitlijning</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Tab Breedte:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Nieuw Thema</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Thema&apos;s</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Bittere luchten</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Betovering</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Rustige Blues</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Oude school</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Ruimtedromen</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Spionnenspel</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Kalmte</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Schrijftafel</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nieuw</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Aangepast</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importeren</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporteren</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Verwijder thema &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Thema&apos;s(%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Thema importeren</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Thema exporteren</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Timer verwijderen?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;woorden:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;pagina&apos;s:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;paragrafen:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;tekens:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Tijdsduur instellen</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Tijd instellen</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Duur:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Tijd:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Memo:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Geen timers ingesteld</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Timer</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Recent</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Timer instelling beeindigen?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Thema wordt geladen</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Geluiden worden geladen</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Unbenannt</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Bestand openen</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Over FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Een simpele schermvullende tekstverwerker</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Uitgegeven onder de  &lt;a href=%1&gt;GPL 3&lt;/a&gt; licentie</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Maakt gebruik van iconenn van het &lt;a href=%1&gt;Oxygen&lt;/a&gt; iconen thema</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Gebruikt onder de &lt;a href=%1&gt;LGPL 3&lt;/a&gt;  licentie</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Tekens: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Pagina&apos;s: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Paragrafen: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Woorden: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Bestand %1 wordt geopend</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(naamloos %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Laat alle documenten zien</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Schakel naar volgend document</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Schakel naar vorig document</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Schakel naar eerste document</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Schakel naar laatste document</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Schakel naar document %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Instellingen inladen</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>De noodopslag is niet beschrijfbaar.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter is niet netjes afgesloten.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Veiligheidskopie herstellen?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Enkele bestanden konden niet geopend worden.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Enkele bestanden zijn in alleen lezen mode geopend.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; is nieuwer dan de versie in de tussenopslag.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Nieuwer bestand overschrijven ?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Veranderingen opslaan ?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Veranderingen in bestand &apos;%1&apos; opslaan voor het afsluiten</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>De veranderingen zullen verloren gaan als ze niet opgeslagen worden</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Typemachinegeluiden konden niet geladen worden.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Openen...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Her&amp;laden</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>Op&amp;slaan</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Opslaan &amp;als...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Hernoemen...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>&amp;Alles opslaan</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Beheer sessies</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nieuwe sessie</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>A&amp;fdrukken...</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Pagina instellingen</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Afsl&amp;uiten</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>S&amp;toppen</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bewerken</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Ongedaan maken</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Herhalen</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>K&amp;nippen</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>K&amp;opieren</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Pl&amp;akken</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Plak &amp;zonder formattering</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl-Shift-V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Alles &amp;Selecteren</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Selecteer &amp;scene</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl-Shift-A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>O&amp;pmaken</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Kop</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Kop &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Kop &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Kop &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Kop &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Kop &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Kop &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normaal</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Dik</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Schuin</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Onderlijnen</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>&amp;Doorhalen</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Strg+G</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Sup&amp;erscript</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Strg+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>Su&amp;bscript</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>&amp;Links uitlijnen</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>&amp;Centreren</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>&amp;Rechts uitlijnen</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>Align &amp;Justify</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>Minder inspringen</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>&amp;Meer inspringen</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Blok &amp;links uitlijnen</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Blok &amp;rechts uitlijnen</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Gereedschappen</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Vinden...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Volge&amp;nde</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>&amp;Achteruit zoeken</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>Ve&amp;rvang...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>&amp;Slimme aanhalingstekens</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>&amp;Dokument bijwerken</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Bijwerken slimme quotes document</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Selecti&amp;e bijwerken</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Bijwerken slimme quotes selectie</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>Spellings&amp;controle...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Taal instellen</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Stopwatch...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>S&amp;ymbolen</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Dagelijkse voortgang</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Instellingen</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>&amp;Gereedschapsbalk tonen</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>&amp;Menu Iconen tonen</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Tekst in focus</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Schermvullend</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>Mi&amp;nimaliseren</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Thema&apos;s...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Instellingen...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Focus uit</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Focus op een lijn</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Focus op 3 lijnen</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Paragraaf</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Focus op paragraaf</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Taal...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Sommige bestanden worden niet ondersteund en kunnen niet geopend worden</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Uit</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Een &amp;lijn</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Drie lijnen</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
</context>
</TS>
